@@ -697,50 +697,6 @@ attr_format_assessment (gint     current,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static gchar *
-format_duration_msec (guint64 msec)
-{
-  gchar *ret;
-  gdouble val;
-  if (msec > 1000 * 60 * 60 * 24 * 365.25)
-    {
-      val = msec / 1000.0 / 60.0 / 60.0 / 24.0 / 365.25;
-      /* Translators: Used for a time-based unit that exceed one year */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f year", "%.1f years", val), val);
-    }
-  else if (msec > 1000 * 60 * 60 * 24)
-    {
-      val = msec / 1000.0 / 60.0 / 60.0 / 24.0;
-      /* Translators: Used for a time-based unit that exceed one day but not one year */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f day", "%.1f days", val), val);
-    }
-  else if (msec > 1000 * 60 * 60)
-    {
-      val = msec / 1000.0 / 60.0 / 60.0;
-      /* Translators: Used for a time-based unit that exceed one hour but not one day */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f hour", "%.1f hours", val), val);
-    }
-  else if (msec > 1000 * 60)
-    {
-      val = msec / 1000.0 / 60.0;
-      /* Translators: Used for a time-based unit that exceed one minute but not one hour */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f minute", "%.1f minutes", val), val);
-    }
-  else if (msec > 1000)
-    {
-      val = msec / 1000.0;
-      /* Translators: Used for a time-based unit that exceed one second but not one minute */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f second", "%.1f seconds", val), val);
-    }
-  else
-    {
-      val = msec;
-      /* Translators: Used for a time-based unit that is counted in milliseconds and doesn't exceed one second */
-      ret = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%.1f msec", "%.1f msecs", val), val);
-    }
-  return ret;
-}
-
 static gchar *
 pretty_to_string (guint64 pretty,
                   gint    pretty_unit)
@@ -752,7 +708,8 @@ pretty_to_string (guint64 pretty,
   switch (pretty_unit)
     {
     case 2: /* SK_SMART_ATTRIBUTE_UNIT_MSECONDS */
-      ret = format_duration_msec (pretty);
+      ret = gdu_utils_format_duration_usec (pretty * 1000,
+                                            GDU_FORMAT_DURATION_FLAGS_SUBSECOND_PRECISION);
       break;
 
     case 3: /* SK_SMART_ATTRIBUTE_UNIT_SECTORS */
@@ -957,7 +914,8 @@ update_updated_label (DialogData *data)
 
   now = time (NULL);
   updated = udisks_drive_ata_get_smart_updated (data->ata);
-  s = gdu_utils_duration_to_string (now - updated, FALSE);
+  s = gdu_utils_format_duration_usec ((now - updated) * G_USEC_PER_SEC,
+                                      GDU_FORMAT_DURATION_FLAGS_NONE);
   s2 = g_strdup_printf (_("%s ago"), s);
   gtk_label_set_text (GTK_LABEL (data->updated_label), s2);
   g_free (s2);
@@ -995,7 +953,8 @@ format_powered_on (UDisksDriveAta *ata)
 
   secs = udisks_drive_ata_get_smart_power_on_seconds (ata);
   if (secs > 0)
-    ret = format_duration_msec (secs * 1000);
+    ret = gdu_utils_format_duration_usec (secs * G_USEC_PER_SEC,
+                                          GDU_FORMAT_DURATION_FLAGS_NONE);
   return ret;
 }
 
@@ -1033,8 +992,7 @@ gdu_ata_smart_get_overall_assessment (UDisksDriveAta *ata,
 
   if (g_strcmp0 (udisks_drive_ata_get_smart_selftest_status (ata), "inprogress") == 0)
     {
-      selftest = g_strdup_printf (_("Self-test in progress — %d%% remaining"),
-                                  udisks_drive_ata_get_smart_selftest_percent_remaining (ata));
+      selftest = g_strdup (_("Self-test in progress"));
     }
 
   /* If self-assessment indicates failure, always return that */
