@@ -229,6 +229,7 @@ create_partition_cb (GObject      *source_object,
   UDisksObject *partition_object = NULL;
   UDisksBlock *partition_block;
   GVariantBuilder options_builder;
+  const gchar *erase;
   const gchar *fstype;
   const gchar *name;
   const gchar *passphrase;
@@ -259,6 +260,7 @@ create_partition_cb (GObject      *source_object,
       goto out;
     }
 
+  erase = gdu_create_filesystem_widget_get_erase (GDU_CREATE_FILESYSTEM_WIDGET (data->create_filesystem_widget));
   fstype = gdu_create_filesystem_widget_get_fstype (GDU_CREATE_FILESYSTEM_WIDGET (data->create_filesystem_widget));
   name = gdu_create_filesystem_widget_get_name (GDU_CREATE_FILESYSTEM_WIDGET (data->create_filesystem_widget));
   passphrase = gdu_create_filesystem_widget_get_passphrase (GDU_CREATE_FILESYSTEM_WIDGET (data->create_filesystem_widget));
@@ -281,6 +283,9 @@ create_partition_cb (GObject      *source_object,
       if (passphrase != NULL && strlen (passphrase) > 0)
         g_variant_builder_add (&options_builder, "{sv}", "encrypt.passphrase", g_variant_new_string (passphrase));
 
+      if (erase != NULL)
+        g_variant_builder_add (&options_builder, "{sv}", "erase", g_variant_new_string (erase));
+
       udisks_block_call_format (partition_block,
                                 fstype,
                                 g_variant_builder_end (&options_builder),
