@@ -120,9 +120,33 @@ restore_disk_image_data_unref (RestoreDiskImageData *data)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static void
+rescan_cb (UDisksBlock   *block,
+           GAsyncResult  *res,
+           gpointer       user_data)
+{
+  RestoreDiskImageData *data = user_data;
+  GError *error = NULL;
+  if (!udisks_block_call_rescan_finish (block,
+                                        res,
+                                        &error))
+    {
+      if (!(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED))
+        gdu_window_show_error (data->window, _("Error rescanning device"), error);
+      g_clear_error (&error);
+    }
+  restore_disk_image_data_unref (data);
+}
+
 static void
 restore_disk_image_data_complete (RestoreDiskImageData *data)
 {
+  /* request that the core OS / kernel rescans the device */
+  udisks_block_call_rescan (data->block,
+                            g_variant_new ("a{sv}", NULL), /* options */
+                            NULL, /* cancellable */
+                            (GAsyncReadyCallback) rescan_cb,
+                            restore_disk_image_data_ref (data));
   g_cancellable_cancel (data->cancellable);
   if (data->dialog != NULL)
     gtk_dialog_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_CANCEL);
@@ -290,9 +314,15 @@ write_cb (GOutputStream  *output_stream,
     {
       s2 = g_format_size (data->total_bytes_read);
       s3 = g_format_size (data->file_size);
-      s4 = gdu_utils_duration_to_string (usec_remaining / G_USEC_PER_SEC, TRUE);
+      s4 = gdu_utils_format_duration_usec (usec_remaining,
+                                           GDU_FORMAT_DURATION_FLAGS_NO_SECONDS);
       s5 = g_format_size (bytes_per_sec);
-      s = g_strdup_printf ("%s of %s copied – %s remaining (%s/sec)", s2, s3, s4, s5);
+      /* Translators: string used for conveying progress of copy operation.
+       * The first two %s are strings with the amount of bytes (ex. "3.4 MB" and "300 MB").
+       * The third %s is the estimated amount of time remaining (ex. "1 minute", "5 minutes" or "Less than a minute").
+       * The fourth %s is the average amount of bytes transfered per second (ex. "8.9 MB").
+       */
+      s = g_strdup_printf (_("%s of %s copied – %s remaining (%s/sec)"), s2, s3, s4, s5);
       g_free (s5);
       g_free (s4);
       g_free (s3);
@@ -302,7 +332,10 @@ write_cb (GOutputStream  *output_stream,
     {
       s2 = g_format_size (data->total_bytes_read);
       s3 = g_format_size (data->file_size);
-      s = g_strdup_printf ("%s of %s copied", s2, s3);
+      /* Translators: string used for convey progress of a copy operation where we don't know time remaining / speed.
+       * The first two %s are strings with the amount of bytes (ex. "3.4 MB" and "300 MB").
+       */
+      s = g_strdup_printf (_("%s of %s copied"), s2, s3);
       g_free (s2);
       g_free (s3);
     }
@@ -553,7 +586,7 @@ open_cb (UDisksBlock  *block,
    */
   if (ioctl (fd, BLKGETSIZE64, &data->block_size) != 0)
     {
-      error = g_error_new (G_IO_ERROR, g_io_error_from_errno (errno), strerror (errno));
+      error = g_error_new (G_IO_ERROR, g_io_error_from_errno (errno), "%s", strerror (errno));
       gdu_window_show_error (data->window, _("Error determining size of device"), error);
       g_error_free (error);
       restore_disk_image_data_complete (data);
